@@ -1,6 +1,8 @@
 /// Contains ready-made [Servers][crate::Server] which can be used in tests.
 #[cfg(feature = "auth")]
 pub mod auth;
+#[cfg(feature = "cloud")]
+pub mod cloud;
 #[cfg(feature = "database")]
 pub mod database;
 #[cfg(feature = "hashi")]
